## File Name: DescribeBy.R
## File Version: 9.041


#####################################################
# S3 method DescribeBy
DescribeBy <- function (object, ...)
{
    UseMethod('DescribeBy')
}
#####################################################
